@@ -1,50 +1,17 @@
 import base64
-import datetime
 import hmac
 import json
 import logging
 import time
 import zlib
 
-import requests
-
 from websocket import WebSocket, WebSocketException, create_connection
 
 
-def get_timestamp():
-    now = datetime.datetime.now()
-    t = now.isoformat("T", "milliseconds")
-    return t + "Z"
-
-
-def get_server_time():
-    url = "https://www.okex.com/api/v5/public/time"
-    response = requests.get(url)
-    if response.status_code == 200:
-        return response.json()['data'][0]['ts']
-    else:
-        return ""
-
-
 def get_local_timestamp():
     return int(time.time())
 
 
-def login_params(timestamp, api_key, passphrase, secret_key):
-    message = timestamp + 'GET' + '/users/self/verify'
-
-    mac = hmac.new(bytes(secret_key, encoding='utf8'), bytes(message, encoding='utf-8'), digestmod='sha256')
-    d = mac.digest()
-    sign = base64.b64encode(d)
-
-    login_param = {"op": "login", "args": [{"apiKey": api_key,
-                                            "passphrase": passphrase,
-                                            "timestamp": timestamp,
-                                            "sign": sign.decode("utf-8")}]}
-    login_str = json.dumps(login_param)
-    return login_str
-
-
 def partial(res):
     data_obj = res['data'][0]
     bids = data_obj['bids']
@@ -238,7 +205,7 @@ class PublicConnect(BaseConnect):
 
     def handle_data(self, res):
         res = eval(res)
-        print(f"{get_timestamp()}\t{res}")
+        print(f"{get_local_timestamp()}\t{res}")
         if 'event' in res:
             return
         l = []
@@ -304,7 +271,14 @@ class PrivateConnect(BaseConnect):
     def subscribe_start(self):
         self.ws = create_connection(self.url)
         timestamp = str(get_local_timestamp())
-        login_str = login_params(timestamp, self.api_key, self.passphrase, self.secret_key)
+        message = timestamp + 'GET' + '/users/self/verify'
+        mac = hmac.new(bytes(self.secret_key, encoding='utf8'), bytes(message, encoding='utf-8'), digestmod='sha256')
+        sign = base64.b64encode(mac.digest()).decode("utf-8")
+        login_param = {"op": "login", "args": [{"apiKey": self.api_key,
+                                                "passphrase": self.passphrase,
+                                                "timestamp": timestamp,
+                                                "sign": sign}]}
+        login_str = json.dumps(login_param)
         self.ws.send(login_str)
         print(f"send: {login_str}")
 
@@ -315,117 +289,3 @@ class TradeConnect(PrivateConnect):
 
     def handle_data(self, res):
         print(res)
-
-
-# WebSocket公共频道 public channels
-# 实盘 real trading
-# url = "wss://ws.okex.com:8443/ws/v5/public"
-# 模拟盘 demo trading
-# url = "wss://ws.okex.com:8443/ws/v5/public?brokerId=9999"
-
-# WebSocket私有频道 private channels
-# 实盘 real trading
-# url = "wss://ws.okex.com:8443/ws/v5/private"
-# 模拟盘 demo trading
-# url = "wss://ws.okex.com:8443/ws/v5/private?brokerId=9999"
-
-'''
-公共频道 public channel
-:param channel: 频道名
-:param instType: 产品类型
-:param instId: 产品ID
-:param uly: 合约标的指数
-'''
-
-# 产品频道
-# channels = [{"channel": "instruments", "instType": "FUTURES"}]
-# 行情频道 tickers channel
-# channels = [{"channel": "tickers", "instId": "BTC-USD-210326"}]
-# 持仓总量频道
-# channels = [{"channel": "open-interest", "instId": "BTC-USD-210326"}]
-# K线频道
-# channels = [{"channel": "candle1m", "instId": "BTC-USD-210326"}]
-# 交易频道
-# channels = [{"channel": "trades", "instId": "BTC-USD-201225"}]
-# 预估交割/行权价格频道
-# channels = [{"channel": "estimated-price", "instType": "FUTURES", "uly": "BTC-USD"}]
-# 标记价格频道
-# channels = [{"channel": "mark-price", "instId": "BTC-USDT-210326"}]
-# 标记价格K线频道
-# channels = [{"channel": "mark-price-candle1D", "instId": "BTC-USD-201225"}]
-# 限价频道
-# channels = [{"channel": "price-limit", "instId": "BTC-USD-201225"}]
-# 深度频道
-# channels = [{"channel": "books", "instId": "BTC-USD-SWAP"}]
-# 期权定价频道
-# channels = [{"channel": "opt-summary", "uly": "BTC-USD"}]
-# 资金费率频道
-# channels = [{"channel": "funding-rate", "instId": "BTC-USD-SWAP"}]
-# 指数K线频道
-# channels = [{"channel": "index-candle1m", "instId": "BTC-USDT"}]
-# 指数行情频道
-# channels = [{"channel": "index-tickers", "instId": "BTC-USDT"}]
-# status频道
-# channels = [{"channel": "status"}]
-
-'''
-私有频道 private channel
-:param channel: 频道名
-:param ccy: 币种
-:param instType: 产品类型
-:param uly: 合约标的指数
-:param instId: 产品ID
-'''
-
-# 账户频道
-# channels = [{"channel": "account", "ccy": "BTC"}]
-# 持仓频道
-# channels = [{"channel": "positions", "instType": "FUTURES", "uly": "BTC-USDT", "instId": "BTC-USDT-210326"}]
-# 订单频道
-# channels = [{"channel": "orders", "instType": "FUTURES", "uly": "BTC-USD", "instId": "BTC-USD-201225"}]
-# 策略委托订单频道
-# channels = [{"channel": "orders-algo", "instType": "FUTURES", "uly": "BTC-USD", "instId": "BTC-USD-201225"}]
-
-'''
-交易 trade
-'''
-
-# 下单
-# trade_param = {"id": "1512", "op": "order", "args": [{"side": "buy", "instId": "BTC-USDT", "tdMode": "isolated", "ordType": "limit", "px": "19777", "sz": "1"}]}
-# 批量下单
-# trade_param = {"id": "1512", "op": "batch-orders", "args": [
-#         {"side": "buy", "instId": "BTC-USDT", "tdMode": "isolated", "ordType": "limit", "px": "19666", "sz": "1"},
-#         {"side": "buy", "instId": "BTC-USDT", "tdMode": "isolated", "ordType": "limit", "px": "19633", "sz": "1"}
-#     ]}
-# 撤单
-# trade_param = {"id": "1512", "op": "cancel-order", "args": [{"instId": "BTC-USDT", "ordId": "259424589042823169"}]}
-# 批量撤单
-# trade_param = {"id": "1512", "op": "batch-cancel-orders", "args": [
-#         {"instId": "BTC-USDT", "ordId": "259432098826694656"},
-#         {"instId": "BTC-USDT", "ordId": "259432098826694658"}
-#     ]}
-# 改单
-# trade_param = {"id": "1512", "op": "amend-order", "args": [{"instId": "BTC-USDT", "ordId": "259432767558135808", "newSz": "2"}]}
-# 批量改单
-# trade_param = {"id": "1512", "op": "batch-amend-orders", "args": [
-#         {"instId": "BTC-USDT", "ordId": "259435442492289024", "newSz": "2"},
-#         {"instId": "BTC-USDT", "ordId": "259435442496483328", "newSz": "3"}
-#     ]}
-
-# loop = asyncio.get_event_loop()
-# 公共频道 不需要登录（行情，持仓总量，K线，标记价格，深度，资金费率等）
-# loop.run_until_complete(subscribe_without_login(url, channels))
-
-# 私有频道 需要登录（账户，持仓，订单等）
-# loop.run_until_complete(subscribe(url, api_key, passphrase, secret_key, channels))
-
-# 交易（下单，撤单，改单等）
-# loop.run_until_complete(trade(url, api_key, passphrase, secret_key, trade_param))
-
-
-# loop.close()
-connect = PublicConnect(channels=[
-    #{"channel": "tickers"},
-    {"channel": "tickers", "instId": "SHIB-USDT"}
-])
-connect.run()
