@@ -13,7 +13,7 @@ class Strategy1(FlaskView):
         self.coin_map = {}
         for detail in data['details']:
             if detail['ccy'] == 'USDT':
-                self.usdt = detail['availBal']
+                self.usdt = float(detail['availBal'])
                 continue
             coin = OkexCoin.instance_by_account(detail)
             if coin.money > 1:
@@ -27,7 +27,7 @@ class Strategy1(FlaskView):
 
     def to_json(self):
         return {
-            "res": self.usdt,
+            "res": round(self.usdt, 2),
             "coins": [coin.to_json() for coin in self.coin_map.values()]
         }
 
@@ -37,4 +37,3 @@ class Strategy1(FlaskView):
         for coin in self.coin_map.values():
             coin.watch()
         return self.to_json()
-
